==> nextcloud-32.0.0p0.tgz: nextcloud/apps/files_downloadlimit/l10n/tr.js <==
OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Dosyalar indirme sınırı",
    "File link share download limit" : "Dosya bağlantısı paylaşımı indirme sınırı",
    "This app allows limiting the number of downloads for external link shares." : "Bu uygulama dış bağlantı paylaşımlarının indirme sayısının sınırlanmasını sağlar.",
    "The minimum limit is 1" : "En az sınır 1 olabilir",
    "Failed to set download limit" : "İndirme sınırı ayarlanamadı",
    "Failed to remove download limit" : "İndirme sınırı kaldırılamadı",
    "Limit downloads" : "İndirmeleri sınırla",
    "Set download limit" : "İndirme sınırını ayarla",
    "Setting a new limit will reset the download count" : "Yeni bir sınır ayarlandığında indirme sayısı sıfırlanır",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["1 indirme daha yapılabilir","{count} indirme daha yapılabilir"],
    "Download limit" : "İndirme sınırı",
    "Configure the default download limit for external shares." : "Dış paylaşımların varsayılan indirme sınırını yapılandırın.",
    "Set default download limit" : "Varsayılan indirme sınırını ayarla",
    "You have reached the maximum amount of downloads allowed" : "En fazla indirme sayısı sınırına ulaştınız",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "Bu paylaşımın indirme sayısı sınırlanmış. Yeni bir indirme başlatmak istediğinize emin misiniz?",
    "Failed to set default download limit" : "Varsayılan indirme sınırı ayarlanamadı"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-32.0.2.tgz: nextcloud/apps/files_downloadlimit/l10n/tr.js <==
OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Dosyalar indirme sınırı",
    "File link share download limit" : "Dosya bağlantısı paylaşımı indirme sınırı",
    "This app allows limiting the number of downloads for external link shares." : "Bu uygulama dış bağlantı paylaşımlarının indirme sayısının sınırlanmasını sağlar.",
    "The minimum limit is 1" : "En az sınır 1 olabilir",
    "Failed to set download limit" : "İndirme sınırı ayarlanamadı",
    "Failed to remove download limit" : "İndirme sınırı kaldırılamadı",
    "Limit downloads" : "İndirmeleri sınırla",
    "Set download limit" : "İndirme sınırını ayarla",
    "Setting a new limit will reset the download count" : "Yeni bir sınır ayarlandığında indirme sayısı sıfırlanır",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["1 indirme daha yapılabilir","{count} indirme daha yapılabilir"],
    "Download limit" : "İndirme sınırı",
    "Configure the default download limit for external shares." : "Dış paylaşımların varsayılan indirme sınırını yapılandırın.",
    "Default download limit for external shares" : "Dış paylaşımlar için varsayılan indirme sınırı",
    "Set default download limit" : "Varsayılan indirme sınırını ayarla",
    "You have reached the maximum amount of downloads allowed" : "En fazla indirme sayısı sınırına ulaştınız",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "Bu paylaşımın indirme sayısı sınırlanmış. Yeni bir indirme başlatmak istediğinize emin misiniz?",
    "Failed to set default download limit" : "Varsayılan indirme sınırı ayarlanamadı",
    "Failed to remove default download limit" : "Varsayılan indirme sınırı kaldırılamadı"
},
"nplurals=2; plural=(n > 1);");
